@@ -132,7 +132,7 @@ class Client(object):
             url = url + f"&tag={tag}"
         return self._get(url)
 
-    def upload_document(self, customer_id: str, document: object, verify_name: str = None, verify_address: str = None, tags: list = list()):
+    def upload_document(self, customer_id: str, document: object, verify_name: str = None, verify_address: str = None, tags: list = list(), verify_id_number: str = None, verify_company: str = None, verify_strings: list = list()):
         """
         Uploads document(s) to a customer. Once the document(s) are uploaded, they will be queued for processing by Inscribe’s fraud detection, parsing,
         and optionally verification algorithms. The file size limit is 50 MB and the page limit for PDFs is 350.
@@ -141,16 +141,25 @@ class Client(object):
         :param verify_name: A name that you want to verify is in a document.
         :param verify_address: An address you want to verify is in a document
         :param tags: A list of descriptive strings chosen by you to group documents together across customers e.g ['onboarding','new_system']
+        :param verify_id_number: A id number name that you want to verify is in a document.
+        :param verify_company: A company name you want to verify is in a document
+        :param verify_strings: A list of dicts with key value pairs for key and input. The key is the identifier for the input and the input is the string you want to verify is in a document e.g [{"key": "phone", input:"929-9774-123"},{"key": "email", input:"john.smith@gmail.com"}]
         """
         url = f"/customers/{customer_id}/documents"
         filename = os.path.basename(document.name)
         verify_entities = []
-        if verify_name or verify_address:
+        if verify_name or verify_address or verify_id_number or verify_company:
             verify_entity = {}
             if verify_name:
                 verify_entity["name"] = verify_name
             if verify_address:
                 verify_entity["address"] = verify_address
+            if verify_id_number:
+                verify_entity["id_number"] = verify_id_number
+            if verify_company:
+                verify_entity["company"] = verify_company
+            if verify_strings:
+                verify_entity["strings"] = verify_strings
             verify_entities.append(verify_entity)
         formatted_tags = []
         for tag in tags:
